@@ -39,7 +39,7 @@ extern "C"
    * Used together with stringprep_check_version() to verify header file
    * and run-time library consistency.
    */
-# define GSASL_VERSION "0.2.13"
+# define GSASL_VERSION "0.2.15"
 
   /* RFC 2222: SASL mechanisms are named by strings, from 1 to 20
    * characters in length, consisting of upper-case letters, digits,
@@ -183,9 +183,13 @@ extern "C"
   extern void gsasl_callback_set (Gsasl * ctx, Gsasl_callback_function cb);
   extern int gsasl_callback (Gsasl * ctx, Gsasl_session * sctx,
 			     Gsasl_property prop);
+
   extern void gsasl_callback_hook_set (Gsasl * ctx, void *hook);
   extern void *gsasl_callback_hook_get (Gsasl * ctx);
 
+  extern void gsasl_session_hook_set (Gsasl_session * sctx, void *hook);
+  extern void *gsasl_session_hook_get (Gsasl_session * sctx);
+
   /* Property handling: property.c */
   extern void gsasl_property_set (Gsasl_session * sctx, Gsasl_property prop,
 				  const char *data);
