@@ -24,13 +24,58 @@
 #define MAX_LINE_LENGTH BUFSIZ
 
 int
-smtp_select_mechanism (char **mechlist)
+smtp_greeting (void)
 {
   char *in;
 
   if (!readln (&in))
     return 0;
 
+  return 1;
+}
+
+int
+smtp_has_starttls (void)
+{
+  char *in, *capa;
+  int has_tls = 0;
+
+  if (!writeln ("EHLO [127.0.0.1]"))
+    return 0;
+
+  do
+    {
+      if (!readln (&in))
+	return 0;
+
+#define TLSGREETING "250-STARTTLS"
+      if (strncmp (in, TLSGREETING, strlen (TLSGREETING)) == 0)
+	has_tls = 1;
+    }
+  while (strncmp (in, "250 ", 4) != 0);
+
+  return has_tls;
+}
+
+int
+smtp_starttls (void)
+{
+  char *in;
+
+  if (!writeln ("STARTTLS"))
+    return 0;
+
+  if (!readln (&in))
+    return 0;
+
+  return 1;
+}
+
+int
+smtp_select_mechanism (char **mechlist)
+{
+  char *in;
+
   if (args_info.server_flag)
     {
       if (!args_info.quiet_given)
@@ -39,7 +84,7 @@ smtp_select_mechanism (char **mechlist)
 	return 0;
       *mechlist = in;
     }
-  else				/* if (args_info.client_flag) */
+  else
     {
       if (!writeln ("EHLO [127.0.0.1]"))
 	return 0;
@@ -62,7 +107,13 @@ smtp_select_mechanism (char **mechlist)
 int
 smtp_authenticate (const char *mech)
 {
-  if (args_info.client_flag)
+  if (args_info.server_flag)
+    {
+      if (!args_info.quiet_given)
+	fprintf (stderr, _("Using mechanism:\n"));
+      puts (mech);
+    }
+  else
     {
       char input[MAX_LINE_LENGTH];
 
@@ -70,12 +121,6 @@ smtp_authenticate (const char *mech)
       if (!writeln (input))
 	return 0;
     }
-  else
-    {
-      if (!args_info.quiet_given)
-	fprintf (stderr, _("Using mechanism:\n"));
-      puts (mech);
-    }
 
   return 1;
 }
@@ -85,10 +130,10 @@ smtp_step_send (const char *data)
 {
   char input[MAX_LINE_LENGTH];
 
-  if (args_info.client_flag)
-    sprintf (input, "%s", data);
-  else
+  if (args_info.server_flag)
     sprintf (input, "334 %s", data);
+  else
+    sprintf (input, "%s", data);
   if (!writeln (input))
     return 0;
 
